@@ -1,11 +1,7 @@
+/* SPDX-License-Identifier: GPL-2.0-or-later */
 /*
  * ipila.c	ILA (Identifier Locator Addressing) support
  *
- *              This program is free software; you can redistribute it and/or
- *              modify it under the terms of the GNU General Public License
- *              as published by the Free Software Foundation; either version
- *              2 of the License, or (at your option) any later version.
- *
  * Authors:	Tom Herbert <tom@herbertland.com>
  */
 
@@ -31,7 +27,8 @@ static void usage(void)
 		"Usage: ip ila add loc_match LOCATOR_MATCH loc LOCATOR [ dev DEV ] OPTIONS\n"
 		"       ip ila del loc_match LOCATOR_MATCH [ loc LOCATOR ] [ dev DEV ]\n"
 		"       ip ila list\n"
-		"OPTIONS := [ csum-mode { adj-transport | neutral-map | neutral-map-auto | no-action } ]\n"
+		"OPTIONS := [ csum-mode { adj-transport | neutral-map |\n"
+		"                         neutral-map-auto | no-action } ]\n"
 		"           [ ident-type { luid | use-format } ]\n");
 
 	exit(-1);
@@ -153,6 +150,7 @@ static int do_list(int argc, char **argv)
 	new_json_obj(json);
 	if (rtnl_dump_filter(&genl_rth, print_ila_mapping, stdout) < 0) {
 		fprintf(stderr, "Dump terminated\n");
+		delete_json_obj();
 		return 1;
 	}
 	delete_json_obj();
