@@ -1,13 +1,8 @@
+/* SPDX-License-Identifier: GPL-2.0-or-later */
 /*
  * rtacct.c		Applet to display contents of /proc/net/rt_acct.
  *
- *		This program is free software; you can redistribute it and/or
- *		modify it under the terms of the GNU General Public License
- *		as published by the Free Software Foundation; either version
- *		2 of the License, or (at your option) any later version.
- *
  * Authors:	Alexey Kuznetsov, <kuznet@ms2.inr.ac.ru>
- *
  */
 
 #include <stdio.h>
@@ -18,7 +13,6 @@
 #include <errno.h>
 #include <time.h>
 #include <sys/time.h>
-#include <fnmatch.h>
 #include <sys/file.h>
 #include <sys/socket.h>
 #include <sys/un.h>
@@ -31,7 +25,7 @@
 
 #include "rt_names.h"
 
-#include <SNAPSHOT.h>
+#include "version.h"
 
 int reset_history;
 int ignore_history;
@@ -464,7 +458,7 @@ int main(int argc, char *argv[])
 			break;
 		case 'v':
 		case 'V':
-			printf("rtacct utility, iproute2-ss%s\n", SNAPSHOT);
+			printf("rtacct utility, iproute2-%s\n", version);
 			exit(0);
 		case 'M':
 			/* Some secret undocumented option, nobody
